@@ -69,11 +69,10 @@ class Network(object):
         self.template = None
         self.conf = False
         self.path = os.path.dirname(__file__) + "/templates/template.html"
-        
+
         if notebook:
             self.prep_notebook()
-        
-            
+
     def __str__(self):
         """
         override print to show readable graph data
@@ -210,7 +209,8 @@ class Network(object):
         else:
             node_label = n_id
         if n_id not in self.node_ids:
-            n = Node(n_id, shape, label=node_label, font_color=self.font_color, **options)
+            n = Node(n_id, shape, label=node_label,
+                     font_color=self.font_color, **options)
             self.nodes.append(n.options)
             self.node_ids.append(n_id)
             self.node_map[n_id] = n.options
@@ -239,7 +239,8 @@ class Network(object):
 
         :type nodes: list
         """
-        valid_args = ["size", "value", "title", "x", "y", "label", "color"]
+        valid_args = ["size", "value", "title",
+            "x", "y", "label", "color", "shape"]
         for k in kwargs:
             assert k in valid_args, "invalid arg '" + k + "'"
 
@@ -264,7 +265,7 @@ class Network(object):
                 # or node could be string
                 assert isinstance(node, str)
                 self.add_node(node, **nd[node])
-            
+
     def num_nodes(self):
         """
         Return number of nodes
@@ -354,7 +355,7 @@ class Network(object):
         if not edge_exists:
             e = Edge(source, to, self.directed, **options)
             self.edges.append(e.options)
-            
+
     def add_edges(self, edges):
         """
         This method serves to add multiple edges between existing nodes
@@ -404,15 +405,18 @@ class Network(object):
         check_html(name)
         self.write_html(name)
 
-    def write_html(self, name, notebook=False):
+    def generate_html(self, notebook=False):
         """
-        This method gets the data structures supporting the nodes, edges,
-        and options and updates the template to write the HTML holding
+        This method generates HTML from the data structures supporting the nodes, edges,
+        and options and updates the template to generate the HTML holding
         the visualization.
 
-        :type name_html: str
+        :type notebook: bool
+
+        Returns
+        :type out: str
         """
-        check_html(name)
+
         # here, check if an href is present in the hover data
         use_link_template = False
         for n in self.nodes:
@@ -444,19 +448,32 @@ class Network(object):
         else:
             physics_enabled = self.options.physics.enabled
 
-        self.html = template.render(height=height,
-                                    width=width,
-                                    nodes=nodes,
-                                    edges=edges,
-                                    heading=heading,
-                                    options=options,
-                                    physics_enabled=physics_enabled,
-                                    use_DOT=self.use_DOT,
-                                    dot_lang=self.dot_lang,
-                                    widget=self.widget,
-                                    bgcolor=self.bgcolor,
-                                    conf=self.conf,
-                                    tooltip_link=use_link_template)
+        out = template.render(height=height,
+                              width=width,
+                              nodes=nodes,
+                              edges=edges,
+                              heading=heading,
+                              options=options,
+                              physics_enabled=physics_enabled,
+                              use_DOT=self.use_DOT,
+                              dot_lang=self.dot_lang,
+                              widget=self.widget,
+                              bgcolor=self.bgcolor,
+                              conf=self.conf,
+                              tooltip_link=use_link_template)
+
+        return out
+
+    def write_html(self, name, notebook=False):
+        """
+        This method gets the data structures supporting the nodes, edges,
+        and options and updates the template to write the HTML holding
+        the visualization.
+
+        :type name_html: str
+        """
+        check_html(name)
+        self.html = self.generate_html(notebook=notebook)
 
         with open(name, "w+") as out:
             out.write(self.html)
@@ -569,7 +586,7 @@ class Network(object):
         return self.get_adj_list()[node]
 
     def from_nx(self, nx_graph, node_size_transf=(lambda x: x), edge_weight_transf=(lambda x: x),
-                default_node_size=10, default_edge_weight=1):
+                default_node_size =10, default_edge_weight=1, show_edge_weights=True):
         """
         This method takes an exisitng Networkx graph and translates
         it to a PyVis graph format that can be accepted by the VisJs
@@ -598,23 +615,25 @@ class Network(object):
         >>> nt.show("nx.html")
         """
         assert(isinstance(nx_graph, nx.Graph))
-        edges = nx_graph.edges(data=True)
-        nodes = nx_graph.nodes(data=True)
+        edges=nx_graph.edges(data = True)
+        nodes=nx_graph.nodes(data = True)
 
         if len(edges) > 0:
             for e in edges:
                 if 'size' not in nodes[e[0]].keys():
-                    nodes[e[0]]['size'] = default_node_size
-                nodes[e[0]]['size'] = int(node_size_transf(nodes[e[0]]['size']))
+                    nodes[e[0]]['size']=default_node_size
+                nodes[e[0]]['size']=int(node_size_transf(nodes[e[0]]['size']))
                 if 'size' not in nodes[e[1]].keys():
-                    nodes[e[1]]['size'] = default_node_size
-                nodes[e[1]]['size'] = int(node_size_transf(nodes[e[1]]['size']))
+                    nodes[e[1]]['size']=default_node_size
+                nodes[e[1]]['size']=int(node_size_transf(nodes[e[1]]['size']))
                 self.add_node(e[0], **nodes[e[0]])
                 self.add_node(e[1], **nodes[e[1]])
 
                 if 'weight' not in e[2].keys():
-                    e[2]['weight'] = default_edge_weight
-                e[2]['weight'] = edge_weight_transf(e[2]['weight'])
+                    e[2]['weight']=default_edge_weight
+                e[2]['weight']=edge_weight_transf(e[2]['weight'])
+                if show_edge_weights:
+                    e[2]["label"] = e[2]["weight"]
                 self.add_edge(e[0], e[1], **e[2])
 
         for node in nx.isolates(nx_graph):
@@ -633,9 +652,9 @@ class Network(object):
     def get_node(self, n_id):
         """
         Lookup node by ID and return it.
-        
+
         :param n_id: The ID given to the node.
-        
+
         :returns: dict containing node properties
         """
         return self.node_map[n_id]
@@ -659,7 +678,7 @@ class Network(object):
     ):
         """
         BarnesHut is a quadtree based gravity model. It is the fastest. default
-        and recommended solver for non-heirarchical layouts.
+        and recommended solver for non-hierarchical layouts.
 
         :param gravity: The more negative the gravity value is, the stronger the
                         repulsion is.
